==> easywebpack-cli-4.1.0.tgz: package/lib/ask.js <==
'use strict';
const chalk = require('chalk');
exports.boilerplateChoice = [
  {
    name: `Create ${chalk.green('Vue')} Application`,
    value: 'boilerplate-vue'
  },
  {
    name: `Create ${chalk.green('React')} Application`,
    value: 'boilerplate-react'
  },
  {
    name: `Create ${chalk.green('Egg + Vue')} Application`,
    value: 'boilerplate-egg-vue'
  },
  {
    name: `Create ${chalk.green('Egg + React')} Application`,
    value: 'boilerplate-egg-react'
  },
  {
    name: `Create ${chalk.green('Weex')} Application`,
    value: 'easywebpack-weex-boilerplate'
  },
  {
    name: `Create ${chalk.green('HTML')} Application`,
    value: 'easywebpack-multiple-html-boilerplate'
  },
  {
    name: `Create ${chalk.green('NPM')} Package Template`,
    value: 'npm-package-code-template',
    choices: ['name', 'description', 'npm'],
    run: 'npm test'
  }
];

exports.boilerplateDetailChoice = {
  'boilerplate-vue': [
    {
      name: `Create ${chalk.green('Vue Single Page')} Application`,
      value: 'vue-boilerplate',
      pkgName: 'easywebpack-vue-boilerplate'
    }
  ],
  'boilerplate-react': [
    {
      name: `Create ${chalk.green('React')} ${chalk.yellow('Webpack')} Application`,
      value: 'easy-react-app-template',
      pkgName: 'easy-react-app-template',
      choices: ['name', 'description', 'npm'],
    },
    {
      name: `Create ${chalk.green('React Single Page')} Application`,
      value: 'react-boilerplate',
      pkgName: 'easywebpack-react-boilerplate'
    }
  ],
  'boilerplate-egg-vue': [
    {
      name: `Create ${chalk.green('Egg + Vue')} ${chalk.yellow('Element Admin')} Application`,
      value: 'easy-element-admin',
      pkgName: 'easy-element-admin'
    },
    {
      name: `Create ${chalk.green('Egg + Vue + Nunjucks')} ${chalk.yellow('HTML')} Application`,
      value: 'egg-vue-html',
      pkgName: 'egg-vue-html-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + Vue + Nunjucks')} ${chalk.yellow('Asset Render')} Application`,
      value: 'egg-vue-asset',
      pkgName: 'egg-vue-asset-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + Vue')} ${chalk.yellow('Server Side Render')} Awesome Application`,
      value: 'egg-vue',
      pkgName: 'egg-vue-webpack-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + Vue + TypeScript')} ${chalk.yellow('Server Side Render')} Application`,
      value: 'egg-vue-typescript',
      pkgName: 'egg-vue-typescript-boilerplate'
    },
    {
      name: `Create ${chalk.green('Ves(Egg) Framework - Node Vue TypeScript Isomorphic Framework')} Application`,
      value: 'ves',
      pkgName: 'ves-admin'
    }
  ],
  'boilerplate-egg-react': [
    {
      name: `Create ${chalk.green('Egg + React + Nunjucks')} ${chalk.yellow('HTML')} Application`,
      value: 'egg-react-html-boilerplate',
      pkgName: 'egg-react-html-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React + Nunjucks')} ${chalk.yellow('Asset Render')} Application`,
      value: 'egg-react-asset-boilerplate',
      pkgName: 'egg-react-asset-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React + TypeScript')} ${chalk.yellow('Server Side Render')} Application`,
      value: 'egg-react-typescript',
      pkgName: 'egg-react-typescript-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React')} ${chalk.yellow('Server Side Render')} Awesome Application`,
      value: 'egg-react',
      pkgName: 'egg-react-webpack-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React + React Router + Redux + Ant Design')} ${chalk.yellow('Server Side Render')} Admin Application`,
      value: 'egg-react-spa',
      pkgName: 'egg-react-webpack-spa-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React + React Router + Redux + Ant Design')} ${chalk.yellow('Client Side Render')} Admin Application`,
      value: 'easy-react-admin',
      pkgName: 'easy-react-admin'
    }
  ]
};

exports.projectAskChoice = [
  {
    type: 'input',
    name: 'name',
    message: 'Please input project name:'
  },
  {
    type: 'input',
    name: 'description',
    message: 'Please input project description:'
  },
  {
    type: 'list',
    name: 'style',
    message: 'Please choose css style:',
    choices: [
      {
        name: 'css',
        value: null,
        checked: true
      },
      {
        name: 'sass',
        value: 'scss'
      },
      {
        name: 'less',
        value: 'less'
      },
      {
        name: 'stylus',
        value: 'stylus'
      }
    ]
  },
  {
    type: 'list',
    name: 'npm',
    message: 'Please choose the way to install dependency:',
    choices: [
      {
        name: 'none',
        value: null,
        checked: true
      },
      {
        name: 'npm',
        value: 'npm'
      },
      {
        name: 'yarn',
        value: 'yarn'
      },
      {
        name: 'cnpm',
        value: 'cnpm'
      },
      {
        name: 'tnpm',
        value: 'tnpm'
      }
    ]
  }
];

==> easywebpack-cli-4.4.0.tgz: package/lib/ask.js <==
'use strict';
const chalk = require('chalk');
exports.boilerplateChoice = [
  {
    name: `Create ${chalk.green('Vue')} Application`,
    value: 'boilerplate-vue'
  },
  {
    name: `Create ${chalk.green('React')} Application`,
    value: 'boilerplate-react'
  },
  {
    name: `Create ${chalk.green('Egg + Vue')} Application`,
    value: 'boilerplate-egg-vue'
  },
  {
    name: `Create ${chalk.green('Egg + React')} Application`,
    value: 'boilerplate-egg-react'
  },
  {
    name: `Create ${chalk.green('Weex')} Application`,
    value: 'easywebpack-weex-boilerplate'
  },
  {
    name: `Create ${chalk.green('HTML')} Application`,
    value: 'easywebpack-multiple-html-boilerplate'
  },
  {
    name: `Create ${chalk.green('NPM')} Package Template`,
    value: 'npm-package-code-template',
    choices: ['name', 'description', 'npm'],
    run: 'npm test'
  }
];

exports.boilerplateDetailChoice = {
  'boilerplate-vue': [
    {
      name: `Create ${chalk.green('Vue Single Page')} Application`,
      value: 'vue-boilerplate',
      pkgName: 'easywebpack-vue-boilerplate'
    }
  ],
  'boilerplate-react': [
    {
      name: `Create ${chalk.green('React')} ${chalk.yellow('Webpack')} Application`,
      value: 'easy-react-app-template',
      pkgName: 'easy-react-app-template',
      choices: ['name', 'description', 'npm']
    },
    {
      name: `Create ${chalk.green('React Single Page')} Application`,
      value: 'react-boilerplate',
      pkgName: 'easywebpack-react-boilerplate'
    }
  ],
  'boilerplate-egg-vue': [
    {
      name: `Create ${chalk.green('Egg + Vue + Nunjucks')} ${chalk.yellow('HTML')} Application`,
      value: 'egg-vue-html',
      pkgName: 'egg-vue-html-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + Vue + Nunjucks')} ${chalk.yellow('Asset Render')} Application`,
      value: 'egg-vue-asset',
      pkgName: 'egg-vue-asset-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + Vue')} ${chalk.yellow('Server Side Render(SSR)')} Awesome Application`,
      value: 'egg-vue',
      pkgName: 'egg-vue-webpack-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + Vue + TypeScript')} ${chalk.yellow('Server Side Render(SSR)')} Application`,
      value: 'egg-vue-typescript',
      pkgName: 'egg-vue-typescript-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + Vue + Vuex + Vue-Router')} ${chalk.yellow('Server Side Render(SSR)')} Application`,
      value: 'egg-vue-spa',
      pkgName: 'egg-vue-webpack-spa-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + Vue + Vuex + Vue-Router')} ${chalk.yellow('Client Side Render(CSR)')} Application`,
      value: 'easy-element-admin',
      pkgName: 'easy-element-admin'
    },
    {
      name: `Create ${chalk.green('Vue Server Side Render')} Application for ${chalk.yellow('Res(Egg+Vue)')} Framework`,
      value: 'ves',
      pkgName: 'ves-admin'
    }
  ],
  'boilerplate-egg-react': [
    {
      name: `Create ${chalk.green('Egg + React + Nunjucks')} ${chalk.yellow('HTML')} Application`,
      value: 'egg-react-html-boilerplate',
      pkgName: 'egg-react-html-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React + Nunjucks')} ${chalk.yellow('Asset Render')} Application`,
      value: 'egg-react-asset-boilerplate',
      pkgName: 'egg-react-asset-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React')} ${chalk.yellow('Server Side Render(SSR)')} Awesome Application`,
      value: 'egg-react',
      pkgName: 'egg-react-webpack-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React + TypeScript')} ${chalk.yellow('Server Side Render(SSR)')} Application`,
      value: 'egg-react-typescript',
      pkgName: 'egg-react-typescript-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React + React Router + Redux')} ${chalk.yellow('Server Side Render(SSR)')} Application`,
      value: 'egg-react-spa',
      pkgName: 'egg-react-webpack-spa-boilerplate'
    },
    {
      name: `Create ${chalk.green('Egg + React + React Router + Redux')} ${chalk.yellow('Client Side Render(CSR)')} Application`,
      value: 'easy-react-admin',
      pkgName: 'easy-react-admin'
    },
    {
      name: `Create ${chalk.green('React Server Side Render')} Application for ${chalk.yellow('Res(Egg+React)')} Framework`,
      value: 'res',
      pkgName: 'res-awesome'
    }
  ]
};

exports.projectAskChoice = [
  {
    type: 'input',
    name: 'name',
    message: 'Please input project name:'
  },
  {
    type: 'input',
    name: 'description',
    message: 'Please input project description:'
  },
  {
    type: 'list',
    name: 'style',
    message: 'Please choose css style:',
    choices: [
      {
        name: 'css',
        value: null,
        checked: true
      },
      {
        name: 'sass',
        value: 'scss'
      },
      {
        name: 'less',
        value: 'less'
      },
      {
        name: 'stylus',
        value: 'stylus'
      }
    ]
  },
  {
    type: 'list',
    name: 'npm',
    message: 'Please choose the way to install dependency:',
    choices: [
      {
        name: 'none',
        value: null,
        checked: true
      },
      {
        name: 'npm',
        value: 'npm'
      },
      {
        name: 'yarn',
        value: 'yarn'
      },
      {
        name: 'cnpm',
        value: 'cnpm'
      },
      {
        name: 'tnpm',
        value: 'tnpm'
      }
    ]
  }
];
